==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/es-MX/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'Campos personalizados',
    'field'		                => 'Campo',
    'about_fieldsets_title'		=> 'Acerca de los campos personalizados',
    'about_fieldsets_text'		=> 'Los grupos de campos personalizados te permiten agrupar campos que se usan frecuentemente para determinados modelos de equipos.',
    'custom_format'             => 'Formato a medida...',
    'encrypt_field'      	        => 'Encriptar el valor de este campo en la base de datos',
    'encrypt_field_help'      => 'CUIDADO: Encriptar un campo hace que no se pueda buscar por él.',
    'encrypted'      	        => 'Encriptado',
    'fieldset'      	        => 'Grupo de campos personalizados',
    'qty_fields'      	      => 'Campos de Cantidad',
    'fieldsets'      	        => 'Grupo de campos personalizados',
    'fieldset_name'           => 'Nombre del grupo',
    'field_name'              => 'Nombre del campo',
    'field_values'            => 'Valores de los Campos',
    'field_values_help'       => 'Agregar opciones seleccionables, una por linea. Lineas en blanco ademas de la primera, serán ignoradas.',
    'field_element'           => 'Elemento de formulario',
    'field_element_short'     => 'Elemento',
    'field_format'            => 'Formato',
    'field_custom_format'     => 'Formato personalizado',
    'field_custom_format_help'     => 'Este campo te permite usar una expresión regex para la validación. Debería empezar con "regex:" - por ejemplo, para validar que un valor de campo personalizado contiene un IMEI válido (15 dígitos numéricos), podrías usar <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obligatorio',
    'req'   		              => 'Obl.',
    'used_by_models'   		    => 'Usado Por Modelos',
    'order'   		            => 'Orden',
    'create_fieldset'         => 'Nuevo grupo de campos',
    'create_field'            => 'Nuevo campo personalizado',
    'value_encrypted'      	        => 'El valor de este campo está encriptado en la base de datos. Solo los administradores pueden ver el valor desencriptado',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-MX/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Campos personalizados',
    'manage'                    => 'Manage',
    'field'		                => 'Campo',
    'about_fieldsets_title'		=> 'Acerca de los campos personalizados',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Encriptar el valor de este campo en la base de datos',
    'encrypt_field_help'      => 'CUIDADO: Encriptar un campo hace que no se pueda buscar por él.',
    'encrypted'      	        => 'Encriptado',
    'fieldset'      	        => 'Grupo de campos personalizados',
    'qty_fields'      	      => 'Campos de Cantidad',
    'fieldsets'      	        => 'Grupo de campos personalizados',
    'fieldset_name'           => 'Nombre del grupo',
    'field_name'              => 'Nombre del campo',
    'field_values'            => 'Valores de los Campos',
    'field_values_help'       => 'Agregar opciones seleccionables, una por linea. Lineas en blanco ademas de la primera, serán ignoradas.',
    'field_element'           => 'Elemento de formulario',
    'field_element_short'     => 'Elemento',
    'field_format'            => 'Formato',
    'field_custom_format'     => 'Formato personalizado',
    'field_custom_format_help'     => 'Este campo te permite usar una expresión regex para la validación. Debería empezar con "regex:" - por ejemplo, para validar que un valor de campo personalizado contiene un IMEI válido (15 dígitos numéricos), podrías usar <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obligatorio',
    'req'   		              => 'Obl.',
    'used_by_models'   		    => 'Usado Por Modelos',
    'order'   		            => 'Orden',
    'create_fieldset'         => 'Nuevo grupo de campos',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Nuevo campo personalizado',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'El valor de este campo está encriptado en la base de datos. Solo los administradores pueden ver el valor desencriptado',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code> :db_column </code> but should be :expected </code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
];
